DMA_AXI_CH2

Struct DMA_AXI_CH2 

#[non_exhaustive]
pub struct DMA_AXI_CH2<'a> { /* private fields */ }
Available on crate feature unstable only.
DMA_AXI_CH2 peripheral singleton

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl DMA_AXI_CH2<'_>

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> DMA_AXI_CH2<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.

pub fn bind_dma_in_interrupt(&self, handler: InterruptHandler)

Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn enable_dma_in_interrupt(&self, priority: Priority)

Enables the AXI_PDMA_IN_CH2 peripheral interrupt on the given priority level.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
The interrupt handler will be enabled on the core that calls this function.

Note that a suitable interrupt handler needs to be set up before the first interrupt is triggered, otherwise the default handler will panic. To set up an interrupt handler, use Self::bind_dma_in_interrupt or create a function that has the same (non-mangled) name as the interrupt you want to handle.

Examples
use esp_hal::interrupt::Priority;

#[unsafe(no_mangle)]
unsafe extern "C" fn AXI_PDMA_IN_CH2() {
    // do something
}

peripherals.DMA_AXI_CH2.enable_dma_in_interrupt(Priority::Priority1);
peripherals.DMA_AXI_CH2.disable_dma_in_interrupt_on_all_cores();
pub fn disable_dma_in_interrupt(&self)

Disables the AXI_PDMA_IN_CH2 peripheral interrupt handler on the current CPU core.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
# Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn disable_dma_in_interrupt_on_all_cores(&self)

Disables the AXI_PDMA_IN_CH2 peripheral interrupt handler on all cores.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
pub fn bind_dma_out_interrupt(&self, handler: InterruptHandler)

Binds an interrupt handler to the corresponding interrupt for this peripheral, and enables the interrupt.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn enable_dma_out_interrupt(&self, priority: Priority)

Enables the AXI_PDMA_OUT_CH2 peripheral interrupt on the given priority level.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
The interrupt handler will be enabled on the core that calls this function.

Note that a suitable interrupt handler needs to be set up before the first interrupt is triggered, otherwise the default handler will panic. To set up an interrupt handler, use Self::bind_dma_out_interrupt or create a function that has the same (non-mangled) name as the interrupt you want to handle.

Examples
use esp_hal::interrupt::Priority;

#[unsafe(no_mangle)]
unsafe extern "C" fn AXI_PDMA_OUT_CH2() {
    // do something
}

peripherals.DMA_AXI_CH2.enable_dma_out_interrupt(Priority::Priority1);
peripherals.DMA_AXI_CH2.disable_dma_out_interrupt_on_all_cores();
pub fn disable_dma_out_interrupt(&self)

Disables the AXI_PDMA_OUT_CH2 peripheral interrupt handler on the current CPU core.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.
# Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

pub fn disable_dma_out_interrupt_on_all_cores(&self)

Disables the AXI_PDMA_OUT_CH2 peripheral interrupt handler on all cores.

This function is a very low-level way to work with interrupts. Unless you're writing drivers, this is probably not the interrupt API you want to use.