#[non_exhaustive]pub struct GPIO23<'a> { /* private fields */ }Expand description
GPIO23 peripheral singleton
Implementations
Sourceimpl<'d> GPIO23<'d>
impl<'d> GPIO23<'d>
Sourcepub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)
Available on crate feature unstable only.
pub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)
unstable only.Split the pin into an input and output signal.
Peripheral signals allow connecting peripherals together without using external hardware.
Safety
The caller must ensure that peripheral drivers don’t configure the same
GPIO at the same time in multiple places. This includes clones of the
InputSignal struct, as well as the OutputSignal struct.
let (rx, tx) = unsafe { peripherals.GPIO2.split() };
// rx and tx can then be passed to different peripherals to connect them.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourceimpl GPIO23<'_>
impl GPIO23<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.