GPIO50

Struct GPIO50 

#[non_exhaustive]
pub struct GPIO50<'a> { /* private fields */ }
GPIO50 peripheral singleton

Implementations

Source

impl<'d> GPIO50<'d>

pub unsafe fn split(self) -> (InputSignal<'d>, OutputSignal<'d>)

Available on crate feature unstable only.

Split the pin into an input and output signal.

Peripheral signals allow connecting peripherals together without using external hardware.

Safety

The caller must ensure that peripheral drivers don’t configure the same GPIO at the same time in multiple places. This includes clones of the InputSignal struct, as well as the OutputSignal struct.

let (rx, tx) = unsafe { peripherals.GPIO2.split() };
// rx and tx can then be passed to different peripherals to connect them.
Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Source

impl GPIO50<'_>

pub unsafe fn steal() -> Self

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub unsafe fn clone_unchecked(&self) -> Self

Unsafely clone this peripheral reference.

Safety

You must ensure that you’re only using one instance of this type at a time.

pub fn reborrow(&mut self) -> GPIO50<'_>

Creates a new peripheral reference with a shorter lifetime.

Use this method if you would like to keep working with the peripheral after you dropped the driver that consumes this.