#[non_exhaustive]pub struct MEMSPI2<'a> { /* private fields */ }unstable only.Expand description
MEMSPI2 peripheral singleton
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl MEMSPI2<'_>
impl MEMSPI2<'_>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Unsafely create an instance of this peripheral out of thin air.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourcepub unsafe fn clone_unchecked(&self) -> Self
pub unsafe fn clone_unchecked(&self) -> Self
Unsafely clone this peripheral reference.
Safety
You must ensure that you’re only using one instance of this type at a time.
Sourceimpl MEMSPI2<'_>
impl MEMSPI2<'_>
Sourcepub const PTR: *const <MEMSPI2 as Deref>::Target = pac::MEMSPI2::PTR
pub const PTR: *const <MEMSPI2 as Deref>::Target = pac::MEMSPI2::PTR
Pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub const fn ptr() -> *const <MEMSPI2 as Deref>::Target
pub const fn ptr() -> *const <MEMSPI2 as Deref>::Target
Return the pointer to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn regs<'a>() -> &'a <MEMSPI2 as Deref>::Target
pub fn regs<'a>() -> &'a <MEMSPI2 as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Sourcepub fn register_block(&self) -> &<MEMSPI2 as Deref>::Target
pub fn register_block(&self) -> &<MEMSPI2 as Deref>::Target
Return a reference to the register block
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.